==> basex_7.9.orig.tar.gz: basex-7.9/basex-tests/src/test/java/org/basex/qt3ts/FnTests.java <==
package org.basex.qt3ts;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.junit.runners.Suite.SuiteClasses;

import org.basex.qt3ts.fn.*;

/**
 * Test suite for the "fn" test group.
 *
 * @author BaseX Team 2005-14, BSD License
 * @author Leo Woerteler
 */
@RunWith(Suite.class)
@SuiteClasses({
  FnAbs.class,
  FnAdjustDateTimeToTimezone.class,
  FnAdjustDateToTimezone.class,
  FnAdjustTimeToTimezone.class,
  FnAnalyzeString.class,
  FnAvailableEnvironmentVariables.class,
  FnAvg.class,
  FnBaseUri.class,
  FnBoolean.class,
  FnCeiling.class,
  FnCodepointEqual.class,
  FnCodepointsToString.class,
  FnCollection.class,
  FnCompare.class,
  FnConcat.class,
  FnContains.class,
  FnCount.class,
  FnCurrentDate.class,
  FnCurrentDateTime.class,
  FnCurrentTime.class,
  FnData.class,
  FnDateTime.class,
  FnDayFromDate.class,
  FnDayFromDateTime.class,
  FnDaysFromDuration.class,
  FnDeepEqual.class,
  FnDefaultCollation.class,
  FnDistinctValues.class,
  FnDoc.class,
  FnDocAvailable.class,
  FnDocumentUri.class,
  FnEmpty.class,
  FnEncodeForUri.class,
  FnEndsWith.class,
  FnEnvironmentVariable.class,
  FnError.class,
  FnEscapeHtmlUri.class,
  FnExactlyOne.class,
  FnExists.class,
  FnFalse.class,
  FnFilter.class,
  FnFloor.class,
  FnFoldLeft.class,
  FnFoldRight.class,
  FnFormatDate.class,
  FnFormatDateTime.class,
  FnFormatInteger.class,
  FnFormatNumber.class,
  FnFormatTime.class,
  FnFunctionArity.class,
  FnFunctionLookup.class,
  FnFunctionName.class,
  FnGenerateId.class,
  FnHasChildren.class,
  FnHead.class,
  FnHoursFromDateTime.class,
  FnHoursFromDuration.class,
  FnHoursFromTime.class,
  FnId.class,
  FnIdref.class,
  FnImplicitTimezone.class,
  FnInScopePrefixes.class,
  FnIndexOf.class,
  FnInnermost.class,
  FnInsertBefore.class,
  FnIriToUri.class,
  FnLang.class,
  FnLast.class,
  FnLocalName.class,
  FnLocalNameFromQName.class,
  FnLowerCase.class,
  FnMap.class,
  FnMapPairs.class,
  FnMatches.class,
  FnMatchesRe.class,
  FnMax.class,
  FnMin.class,
  FnMinutesFromDateTime.class,
  FnMinutesFromDuration.class,
  FnMinutesFromTime.class,
  FnMonthFromDate.class,
  FnMonthFromDateTime.class,
  FnMonthsFromDuration.class,
  FnName.class,
  FnNamespaceUri.class,
  FnNamespaceUriForPrefix.class,
  FnNamespaceUriFromQName.class,
  FnNilled.class,
  FnNodeName.class,
  FnNormalizeSpace.class,
  FnNormalizeUnicode.class,
  FnNot.class,
  FnNumber.class,
  FnOneOrMore.class,
  FnOutermost.class,
  FnParseXml.class,
  FnParseXmlFragment.class,
  FnPath.class,
  FnPosition.class,
  FnPrefixFromQName.class,
  FnQName.class,
  FnRemove.class,
  FnReplace.class,
  FnResolveQName.class,
  FnResolveUri.class,
  FnReverse.class,
  FnRoot.class,
  FnRound.class,
  FnRoundHalfToEven.class,
  FnSecondsFromDateTime.class,
  FnSecondsFromDuration.class,
  FnSecondsFromTime.class,
  FnSerialize.class,
  FnStartsWith.class,
  FnStaticBaseUri.class,
  FnString.class,
  FnStringJoin.class,
  FnStringLength.class,
  FnStringToCodepoints.class,
  FnSubsequence.class,
  FnSubstring.class,
  FnSubstringAfter.class,
  FnSubstringBefore.class,
  FnSum.class,
  FnTail.class,
  FnTimezoneFromDate.class,
  FnTimezoneFromDateTime.class,
  FnTimezoneFromTime.class,
  FnTokenize.class,
  FnTrace.class,
  FnTranslate.class,
  FnTrue.class,
  FnUnordered.class,
  FnUnparsedText.class,
  FnUnparsedTextAvailable.class,
  FnUnparsedTextLines.class,
  FnUpperCase.class,
  FnUriCollection.class,
  FnYearFromDate.class,
  FnYearFromDateTime.class,
  FnYearsFromDuration.class,
  FnZeroOrOne.class
})
public class FnTests { }

==> basex_8.2.3.orig.tar.gz: basex-8.2.3/basex-tests/src/test/java/org/basex/qt3ts/FnTests.java <==
package org.basex.qt3ts;

import org.basex.qt3ts.fn.*;
import org.junit.runner.*;
import org.junit.runners.*;
import org.junit.runners.Suite.SuiteClasses;

/**
 * Test suite for the "fn" test group.
 *
 * @author BaseX Team 2005-15, BSD License
 * @author Leo Woerteler
 */
@RunWith(Suite.class)
@SuiteClasses({
  FnAbs.class,
  FnAdjustDateTimeToTimezone.class,
  FnAdjustDateToTimezone.class,
  FnAdjustTimeToTimezone.class,
  FnAnalyzeString.class,
  FnAvailableEnvironmentVariables.class,
  FnAvg.class,
  FnBaseUri.class,
  FnBoolean.class,
  FnCeiling.class,
  FnCodepointEqual.class,
  FnCodepointsToString.class,
  FnCollection.class,
  FnCompare.class,
  FnConcat.class,
  FnContains.class,
  FnCount.class,
  FnCurrentDate.class,
  FnCurrentDateTime.class,
  FnCurrentTime.class,
  FnData.class,
  FnDateTime.class,
  FnDayFromDate.class,
  FnDayFromDateTime.class,
  FnDaysFromDuration.class,
  FnDeepEqual.class,
  FnDefaultCollation.class,
  FnDistinctValues.class,
  FnDoc.class,
  FnDocAvailable.class,
  FnDocumentUri.class,
  FnEmpty.class,
  FnEncodeForUri.class,
  FnEndsWith.class,
  FnEnvironmentVariable.class,
  FnError.class,
  FnEscapeHtmlUri.class,
  FnExactlyOne.class,
  FnExists.class,
  FnFalse.class,
  FnFilter.class,
  FnFloor.class,
  FnFoldLeft.class,
  FnFoldRight.class,
  FnFormatDate.class,
  FnFormatDateTime.class,
  FnFormatInteger.class,
  FnFormatNumber.class,
  FnFormatTime.class,
  FnFunctionArity.class,
  FnFunctionLookup.class,
  FnFunctionName.class,
  FnGenerateId.class,
  FnHasChildren.class,
  FnHead.class,
  FnHoursFromDateTime.class,
  FnHoursFromDuration.class,
  FnHoursFromTime.class,
  FnId.class,
  FnIdref.class,
  FnImplicitTimezone.class,
  FnInScopePrefixes.class,
  FnIndexOf.class,
  FnInnermost.class,
  FnInsertBefore.class,
  FnIriToUri.class,
  FnLang.class,
  FnLast.class,
  FnLocalName.class,
  FnLocalNameFromQName.class,
  FnLowerCase.class,
  FnMap.class,
  FnMapPairs.class,
  FnMatches.class,
  FnMatchesRe.class,
  FnMax.class,
  FnMin.class,
  FnMinutesFromDateTime.class,
  FnMinutesFromDuration.class,
  FnMinutesFromTime.class,
  FnMonthFromDate.class,
  FnMonthFromDateTime.class,
  FnMonthsFromDuration.class,
  FnName.class,
  FnNamespaceUri.class,
  FnNamespaceUriForPrefix.class,
  FnNamespaceUriFromQName.class,
  FnNilled.class,
  FnNodeName.class,
  FnNormalizeSpace.class,
  FnNormalizeUnicode.class,
  FnNot.class,
  FnNumber.class,
  FnOneOrMore.class,
  FnOutermost.class,
  FnParseXml.class,
  FnParseXmlFragment.class,
  FnPath.class,
  FnPosition.class,
  FnPrefixFromQName.class,
  FnQName.class,
  FnRemove.class,
  FnReplace.class,
  FnResolveQName.class,
  FnResolveUri.class,
  FnReverse.class,
  FnRoot.class,
  FnRound.class,
  FnRoundHalfToEven.class,
  FnSecondsFromDateTime.class,
  FnSecondsFromDuration.class,
  FnSecondsFromTime.class,
  FnSerialize.class,
  FnStartsWith.class,
  FnStaticBaseUri.class,
  FnString.class,
  FnStringJoin.class,
  FnStringLength.class,
  FnStringToCodepoints.class,
  FnSubsequence.class,
  FnSubstring.class,
  FnSubstringAfter.class,
  FnSubstringBefore.class,
  FnSum.class,
  FnTail.class,
  FnTimezoneFromDate.class,
  FnTimezoneFromDateTime.class,
  FnTimezoneFromTime.class,
  FnTokenize.class,
  FnTrace.class,
  FnTranslate.class,
  FnTrue.class,
  FnUnordered.class,
  FnUnparsedText.class,
  FnUnparsedTextAvailable.class,
  FnUnparsedTextLines.class,
  FnUpperCase.class,
  FnUriCollection.class,
  FnYearFromDate.class,
  FnYearFromDateTime.class,
  FnYearsFromDuration.class,
  FnZeroOrOne.class
})
public class FnTests { }
